#include <eGizmo_Serial_Matrix.h>
#include <SoftwareSerial.h>


serialMatrixDisplay::serialMatrixDisplay (SoftwareSerial *ss) {
  hwSerial = NULL;
  swSerial = ss;
  mySerial = swSerial;
}

serialMatrixDisplay::serialMatrixDisplay (HardwareSerial *hs) {
  swSerial = NULL;
  hwSerial = hs;
  mySerial = hwSerial;
}

void serialMatrixDisplay::begin(uint32_t baudrate) {
   delay(1000);  // one second delay to let the module 'boot up'

   if (hwSerial) hwSerial->begin(baudrate);

   if (swSerial) swSerial->begin(baudrate);
 }

void serialMatrixDisplay::write(String cmd) {
     manualSend(preFix);
     manualSend(cmd);
     manualSend(sufFix);
 }

void serialMatrixDisplay::attachRDYpin(uint8_t pinNum) {
     pinMode(pinNum, INPUT);
     RDYpin = pinNum;
 }

void serialMatrixDisplay::dettachRDYpin(void){
   RDYpin = NULL;
 }

void serialMatrixDisplay::end(void) {
   if (hwSerial) hwSerial->end();

   if (swSerial) swSerial->end();
 }

void serialMatrixDisplay::manualSend(String cmd) {
   mySerial->print(cmd);
   delay(2);// essential
 }

bool serialMatrixDisplay::delayUntilClear(int timeOut){
   if (RDYpin) {
     uint8_t	i;

     //  Give time for the display unit to activate busy output
     for(i=0;i<timeOut;i++){
       if(digitalRead(RDYpin) == 0) break;
     }

     //wait until ready
     while(digitalRead(RDYpin == 0));
     return true;

   }else{
     return false;
   }

}

void serialMatrixDisplay::clearDisplay(void) {
   write(clearAll);
}

void serialMatrixDisplay::alignCenter(void) {
   write(alignTextCenter);
}

void serialMatrixDisplay::alignLeft(void) {
   write(alignTextLeft);
}

void serialMatrixDisplay::alignRight(void) {
   write(alignTextRight);
}

void serialMatrixDisplay::testAllChars(void) {
   write(testMode);
}

void serialMatrixDisplay::flashingText(void) {
   write(flashText);
}

void serialMatrixDisplay::clearAllDropMsgIn(String textDisplay) {

   manualSend(preFix);

   manualSend(clearAllDropIn);

   manualSend(textDisplay);

   manualSend(sufFix);

}

void serialMatrixDisplay::overwriteDropInA(String textDisplay) {

   manualSend(preFix);

   manualSend(overwriteAllDropInA);

   manualSend(textDisplay);

   manualSend(sufFix);

}

void serialMatrixDisplay::overwriteDropInB(String textDisplay) {

   manualSend(preFix);

   manualSend(overwriteAllDropInB);

   manualSend(textDisplay);

   manualSend(sufFix);

}

void serialMatrixDisplay::pushUpScrollIn(String textDisplay) {

   manualSend(preFix);

   manualSend(scrollUpPushOld);

   manualSend(textDisplay);

   manualSend(sufFix);

}

void serialMatrixDisplay::pushDownscrollIn(String textDisplay) {

   manualSend(preFix);

   manualSend(scrollDownPushOld);

   manualSend(textDisplay);

   manualSend(sufFix);

}

void serialMatrixDisplay::clearDispScrollLeft(String textDisplay) {

   manualSend(preFix);

   manualSend(clearAllScrollInLeft);

   manualSend(textDisplay);

   manualSend(sufFix);

}

void serialMatrixDisplay::clearAllthenDisplay(String textDisplay) {

   manualSend(preFix);

   manualSend(clearAllDisplayMsg);

   manualSend(textDisplay);

   manualSend(sufFix);

}

void serialMatrixDisplay::scrollOut(String anim) {

   manualSend(preFix);

   if ((anim == "L") || (anim == "LEFT") || (anim == "Left") || (anim == "left")) {
     manualSend(scrollOutLeft);
   }else if ((anim == "U")|| (anim == "UP") || (anim == "Up") || (anim == "up")) {
     manualSend(scrollOutUp);
   } else if ((anim == "D") || (anim == "DOWN") || (anim == "Down") || (anim == "down")) {
     manualSend(scrollOutDown);
   }

   manualSend(sufFix);

}

long serialMatrixDisplay::delaydropInA(String textToDelay){
 uint8_t val = textToDelay.length();

 uint8_t delayTime = val*410;


}
