/*
COMMANDS:
Key characters
       KeyChar HEX      Does
       ESC     1B     prefix key character

 Message IN Animation

       0       00     Clear all then drop in
       1       01     Overwrite old then drop in (skips spaces)
       2       02     Overwrite old then drop in (includes spaces)
       U       55     Scroll up, old message is pushed out
       D       44     Scroll down, old message is pushed out
       S       53     Clear display, scroll left
       A       41     Clear display, display new message, No Animation

 Message OUT Animations
       s       73     Scroll left
       d       64     Scroll down
       u       75     Scroll up
       f       66     Flashing text
       ESC     1B     Clear All

 Message Positioning
       C       43     Align center
       L       4C     Align Left
       R       52     Align Right

 Test
       T       T or 54  Display the entire character set

 ex. add "\x" before the HEX value of a key character
     for [ESC] =  "\x1B" then add carriage return character "\r" or newline character "\n"
     It shoud be like this: "Serial.print("\x1B\r");"

 Codes by e-Gizmo Mechatronix Central
 http://wwww.e-gizmo.com
 October 26, 2017
*/
#ifndef eGizmo_Serial_Matrix_h
#define eGizmo_Serial_Matrix_h

#include <Arduino.h>
#include <SoftwareSerial.h>

// Class Member Variables
// These are initialized at startup
#define preFix "\x1B"
#define sufFix "\r"


#define clearAllDropIn "\x30"
#define overwriteAllDropInA "\x31"
#define overwriteAllDropInB "\x32"
#define scrollUpPushOld "\x55"
#define scrollDownPushOld "\x44"
#define clearAllScrollInLeft "\x53"
#define clearAllDisplayMsg "\x41"
 #define clearAll "\x1B"

#define scrollOutLeft "\x73"
#define scrollOutDown "\x64"
#define scrollOutUp "\x75"
#define flashText "\x66"

#define alignTextCenter "\x43"
#define alignTextLeft "\x4C"
#define alignTextRight "\x52"

#define testMode "\x54"

class serialMatrixDisplay {

  public:
    serialMatrixDisplay (SoftwareSerial *ss);
    serialMatrixDisplay (HardwareSerial *hs);

    void begin(uint32_t baudrate);
    void end(void);

    void write(String cmd);
    void manualSend(String cmd);

    void dettachRDYpin(void);
    void attachRDYpin(uint8_t pinNum);

    bool delayUntilClear(int timeOut = 1000);
    long delaydropInA(String textToDelay);

    void scrollOut(String anim);

    void testAllChars(void);

    void clearDisplay(void);
    void alignCenter(void);
    void alignLeft(void);
    void alignRight(void);
    void flashingText(void);

    void clearAllDropMsgIn(String textDisplay);
    void overwriteDropInA(String textDisplay);
    void overwriteDropInB(String textDisplay);
    void pushUpScrollIn(String textDisplay);
    void pushDownscrollIn(String textDisplay);
    void clearDispScrollLeft(String textDisplay);
    void clearAllthenDisplay(String textDisplay);



  private:
    Stream *mySerial;

    HardwareSerial *hwSerial;
    SoftwareSerial *swSerial;

    uint8_t RDYpin;


};



#endif
